##
##  ucarp.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2010 OpenPKG Foundation e.V. <http://openpkg.net/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         ucarp
Summary:      Common Address Redundancy Protocol (CARP)
URL:          http://www.ucarp.org/
Vendor:       Frank Denis
Packager:     OpenPKG Foundation e.V.
Distribution: OpenPKG Community
Class:        EVAL
Group:        Routing
License:      Specific
Version:      1.5.2
Release:      20100201

#   package options
%option       with_fsl  yes

#   list of sources
Source0:      http://download.pureftpd.org/pub/ucarp/ucarp-%{version}.tar.bz2
Source1:      rc.ucarp
Source2:      fsl.ucarp
Source3:      vip-up.sh
Source4:      vip-down.sh
Patch0:       ucarp.patch

#   build information
Prefix:       %{l_prefix}
BuildRoot:    %{l_buildroot}
BuildPreReq:  OpenPKG, openpkg >= 20060823, libpcap, libiconv
PreReq:       OpenPKG, openpkg >= 20060823, libpcap, libiconv
%if "%{with_fsl}" == "yes"
BuildPreReq:  fsl
PreReq:       fsl
%endif
AutoReq:      no
AutoReqProv:  no

%description
    UCARP allows a couple of hosts to share common virtual IP
    addresses in order to provide automatic failover. It is a
    portable userland implementation of the secure and patent-
    free Common Address Redundancy Protocol (CARP, OpenBSD's
    alternative to the VRRP).

    Strong points of the CARP protocol are very low overhead,
    cryptographically signed messages, interoperability between
    different operating systems, and no need for any dedicated
    extra network link between redundant hosts.

%track
    prog ucarp = {
        version   = %{version}
        url       = http://download.pureftpd.org/pub/ucarp/
        regex     = ucarp-(__VER__)\.tar\.bz2
    }

%prep
    %setup -q
    %patch -p0

%build
    #   configure program
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags} %{l_fsl_ldflags}" \
    LIBS="%{l_fsl_libs} -lpcap" \
    GREP="grep" \
    ./configure \
        --prefix=%{l_prefix} \
        --sysconfdir=%{l_prefix}/etc/ucarp \
        --localstatedir=%{l_prefix}/var/ucarp \
        --with-libiconv-prefix=%{l_prefix} \
        --disable-nls

    #   build program
    %{l_make} %{l_mflags -O}

%install
    #   install program
    rm -rf $RPM_BUILD_ROOT
    %{l_make} %{l_mflags} install-strip AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"

    #   create directory structure
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/etc/fsl \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d \
        $RPM_BUILD_ROOT%{l_prefix}/etc/ucarp \
        $RPM_BUILD_ROOT%{l_prefix}/var/ucarp

    #   install default configuration
    %{l_shtool} install -c -m 755 \
        %{SOURCE vip-down.sh} \
        %{SOURCE vip-up.sh} \
        $RPM_BUILD_ROOT%{l_prefix}/etc/ucarp/

    #   install runcommand script
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE rc.ucarp} \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d/

    #   install OSSP fsl configuration
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE fsl.ucarp} \
        $RPM_BUILD_ROOT%{l_prefix}/etc/fsl/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/ucarp/*' \
        '%config %{l_prefix}/etc/fsl/fsl.ucarp'

%files -f files

%clean
    rm -rf $RPM_BUILD_ROOT

%post
    #   after upgrade, restart service
    [ $1 -eq 2 ] || exit 0
    eval `%{l_rc} ucarp status 2>/dev/null`
    [ ".$ucarp_active" = .yes ] && %{l_rc} ucarp restart
    exit 0

%preun
    #   before erase, stop service and remove log files
    [ $1 -eq 0 ] || exit 0
    %{l_rc} ucarp stop 2>/dev/null
    rm -f $RPM_INSTALL_PREFIX/var/ucarp/*.log >/dev/null 2>&1 || true
    exit 0

